GOOF----LE-8-2.0#-      ]  4  h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  standard-reports		g  budget-flow	
	 	g  filenameS	f  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm	
g  set-current-module	
 	
 	g  process-use-modules	 	 	g  main	 	 	g  
gnc-module	 	 	g  gettext	 	 	g  printf	 	 	g  gnc:module-load	 f  gnucash/report/report-system	!f  gnucash/gnome-utils	"f  Budget Flow	#g  
reportname	$f  Account	%g  optname-accounts	&f  Price Source	'g  optname-price-source	(f  Budget	)g  optname-budget	*f  Period	+g  optname-periods	,f  Report's currency	-g  optname-report-currency	.g  gnc:new-options	/g  gnc:register-option	0g  gnc:make-budget-option	1g  gnc:pagename-general	2f  a	3f  Budget to use.	4g  gnc:make-number-range-option	5f  b	6f  Period number.	7g  gnc:options-add-currency!	8f  d	9g  gnc:options-add-price-source!	:f  c	;g  pricedb-latest	<g  gnc:make-account-list-option	=g  gnc:pagename-accounts	>g  
string-append	?f  Report on these accounts.	@g  "gnc-account-get-descendants-sorted	Ag  gnc-get-current-root-account	Bg  gnc:options-set-default-section	Cg  budget-report-options-generator	Dg  !gnc:html-table-append-row/markup!	Ef  
normal-row	Fg  gnc:make-html-table-cell/markup	Gf  	text-cell	Hg  gnc:html-table-add-budget-row!	Ig  gnc:make-commodity-collector	Jg  for-each	Kg  gnc-account-get-children	Lg  xaccAccountGetCommodity	Mg  #gnc-budget-get-account-period-value	Ng  gnc:make-gnc-monetary	Og  *gnc-budget-get-account-period-actual-value	Pg  add	Qf  number-cell	Rg  gnc:make-html-text	Sg  gnc:html-markup-anchor	Tg  gnc:account-anchor-text	Ug  gnc-account-get-full-name	Vg  gnc:sum-collector-commodity	Wf  total-number-cell	Xg  _	Yf  Total	Zf  :	[g  gnc:html-table-append-row!	\f  "<tr><td colspan='3'><hr></td></tr>	]g  #gnc:html-table-add-budget-accounts!	^g  
assoc-set!	_g   gnc:html-table-add-budget-types!	`g  gnc:gnc-monetary-commodity	ag  gnc:gnc-monetary-amount	bg  "gnc:account-get-type-string-plural	cg  !gnc:html-table-add-budget-totals!	dg  gnc:report-starting	eg  gnc:option-value	fg  gnc:lookup-option	gg  gnc:report-options	hg  inexact->exact	ig  gnc:case-exchange-fn	jg  gnc:make-html-document	kg  gnc:html-document-add-object!	lg   gnc:html-make-no-account-warning	mg  report-title	ng  
gnc:report-id	og  gnc:make-html-table	pg  gnc:optname-reportname	qg  gnc:decompose-accountlist	rg  gnc:html-document-set-title!	sg  sprintf	tf  %s: %s - %s	ug  gnc-budget-get-name	vg  gnc-print-date	wg   gnc-budget-get-period-start-date	xg  $gnc:html-make-generic-budget-warning	yg  gnc:report-finished	zg  budget-renderer	{g  gnc:define-report	|g  version	}g  name	~g  report-guid	f   e6e34fa3b6e748debde3cb3bc76d3e53 g  	menu-path g  gnc:menuname-budget g  options-generator g  rendererC 5     h    ]4
5 4 >  "  G   4 >  "  G  4 >  "  G  4 >  "  G  4 >  "  G  4i 
>  "  G  4i!
>  "  G  "#R$%R&'R()R*+R,-R./01)234+567-89':;<=%>?@A h      ] 45 6            g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
	Z			[	.		[	
 		
   CB   h     ]45  4 45>  "  G  4 4	
	<
5	>  "  G  4 
>  "  G  4 >  "  G  4 4455>  "  G  4 >  "  G   C      g  options
	   g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
	2
		3			3		
	6			8			:			:			8		 	6		)	=		.	?		6	H		8	H		@	?		E	=		N	K		X	M		]	K		f	P		p	Q	8	r	Q	<	w	P	 	T	 	V	 	X	 	X	 	X	 	X	 	Y	 	V	 	T	 	_	 !	 
  g  nameg  budget-report-options-generator CCRDEFG    h(   q  ] 454545 6i      g  
html-table
		( g  markup		( g  text			( g  total1			( g  total2			(  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
	f
		j	0			l		
	l	'		l			m			n		&	k		(	j	 
		(	  g  nameg  gnc:html-table-add-budget-row! CHRIJKLMNOPHQRSTU 
  h   E  ])4 5(  4 54L L5454L L5454L >  "  G  4L>  "  G  L4	4
4 54 5556C      =      g  acct
	  g  comm	  g  bgt-numeric		"  g  bgt-monetary		-  g  act-numeric		;  g  act-monetary		F   g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
 		 		
 		 		 	
	 		  	L	" 		" 	
	% 		- 	
	0 		9 	S	; 		; 	
	> 		F 	
	I 		M 		V 		_ 		c 		l 		z 	7	{ 		~ 	"  	:  	Y  	"  	  	  	    CVHW>XYZ[\ 
     h     ]&45 45 4 O >  "  G  4545	4 44	5
5	>  "  G  4 >  "  G  	 C         g  
html-table
	  g  
acct-table	  g  budget		  g  period		  g  exchange-fn		  g  report-currency		  g  	bgt-total		  g  	act-total		  g  bgt-total-numeric		<  g  act-total-numeric			I   
g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
	z
					}		
 			}		 		2 		< 		? 		I 		L 		R 	1	S 	E	V 	T	Z 	W	\ 	T	^ 	`	` 	E	i 		r 		x 	-	} 	  	 	 	  g  nameg  #gnc:html-table-add-budget-accounts! C]RJ^] h0     ]  4M4L LLLL55NC            g  pair
		* g  key		* g  value		
	*  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
 		 		 		
 	%	
 		
 		 	
	& 		( 	 
		*   C      h0     ]H4 O >  "  G  JC           g  
html-table
		+ g  
acct-table		+ g  budget			+ g  period			+ g  exchange-fn			+ g  report-currency			+ g  accounts-totals			+  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
 
	 		 		 	 		+	  g  nameg   gnc:html-table-add-budget-types! C_RIJP`aHQb    hp     ]!  4L4545>  "  G  4L4545>  "  G  L 456            g  pair
		j g  key		j g  value		
	j g  	bgt-total			j g  	act-total			j  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
 		 		 		
 		
 		 		 		 		 		 	
	 		 	$	$ 	K	/ 	
	8 	
	< 		= 	$	D 	K	O 	
	] 	5	^ 	C	j 	
 		j   CVHW>XYZ     hh   O  ]$45 45 4 O >  "  G  4545 44	5
56       G      g  
html-table
		a g  type-totals		a g  exchange-fn			a g  report-currency			a g  bgt-total-collector			a g  act-total-collector			a g  bgt-total-numeric		8	a g  act-total-numeric		E	a  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm
 
	 		 		
 		 		 		. 		8 		; 		E 		M 	1	N 	E	Q 	T	U 	W	W 	T	Y 	`	[ 	E	a 	 		a	  g  nameg  !gnc:html-table-add-budget-totals! CcRd#1)efg=%h+-'ijklmnopqrsXtuvw_cxy "       h  K  ]Y4>  "  G  444 555	444 5554
444 5555444 555
444 5554545 (  $444 55>  "  G  "  $  "  $  45 
	444 5	
55	
	45
H4445	4544555>  "  G  4
5K4J>  "  G  4>  "  G  
	"  44 5>  "  G  4!>   "  G  C    C      g  
report-obj
	 g  pagename		7 g  optname			7 g  budget	7 g  pagename		=	\ g  optname		=	\ g  accounts		\ g  pagename		e  g  optname		e  g  period	  g  pagename	   g  optname	   g  report-currency	  g  pagename	   g  optname	   g  price-source	  g  exchange-fn	  g  doc	  g  
html-table	' g  pagename		-L g  optname	
-L g  report-name		L g  split-up-accounts	
U g  accounts-totals	X  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm

					
		 		#		/		1
		7		=		B
		E		H		T		V
		\		_		e		j
		m		p		|		~
	 	 	 	 
	 	 	 	 
	 	 	 
	 	 	 	 
	 	 	 	 "	 	 %	 (	 *	 +	 *	(			&	!"%	#4	'3	-5	2
	5	8	D	F
	L3	O9	U3	X:	X3	[?	`@	d@	h@	j@	mA	tB	wB	~B	EB	B	@	?	E	E	F	I	/	0	/	L	 X	  g  nameg  budget-renderer CzR{i|}#i~i Cizi6        g  m
	
	$  g  filenamef  m/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/report/standard-reports/budget-flow.scm		
	%	
	:	
	O	
	d	 
	y	"
		"	 	"
 	#
 	#	 	#
 	&	 	%
 	+	 	+
 	,	! 	,
 	-	 	-
 	.	 	.
 	/	$ 	/
x	2
,	f
	z
 
 

PQRR	SS	TUO
 '	
   C6 